@@ -71,3 +71,15 @@ def test_unicode():
          ("/usr/lib/whatあever.py", 69, 'getあMethod', "return u'あ'")
         ], AttributeError, AttributeError("'NoneType' object has no pants.'"))
     u''.join(format_traceback(*unicode_tb))
+
+
+def test_none_members():
+    """Don't crash if the attrs of an extracted traceback are None.
+
+    This can happen when using mocking.
+
+    """
+    list(format_traceback(
+        [(None, None, None, None)],
+        AttributeError,
+        AttributeError('I have many nasty attributes.')))
