@@ -1,6 +1,7 @@
 """Facilities for wrapping stderr and stdout and dealing with the fallout"""
 
 from __future__ import with_statement
+import __builtin__
 import cmd
 import pdb
 import sys
@@ -30,14 +31,14 @@ def cmdloop(self, *args, **kwargs):
 
     orig_raw_input = raw_input
     if hasattr(sys.stdout, 'stream'):
-        __builtins__.raw_input = unwrapping_raw_input
+        __builtin__.raw_input = unwrapping_raw_input
     # else if capture plugin has replaced it with a StringIO, don't bother.
     try:
         # Interesting things happen when you try to not reference the
         # superclass explicitly.
         ret = cmd.Cmd.cmdloop(self, *args, **kwargs)
     finally:
-        __builtins__.raw_input = orig_raw_input
+        __builtin__.raw_input = orig_raw_input
     return ret
 
 
